@@ -1,40 +1,36 @@
 package OptArgs2::Pager;
 use strict;
 use warnings;
-use OptArgs2::Mo;
 use Carp ();
+use Exporter::Tidy other => [qw/page start_pager stop_pager/];
 use File::Which;
 use IO::Handle;
+use OptArgs2::Pager_CI {
+
+    # User provided arguments
+    auto     => { default => 1, },
+    encoding => { default => ':utf8', },
+    pager    => { default => \&_build_pager, },
+
+    # Attributes
+    fh => {
+        init_arg => undef,
+        is       => 'rw',
+        default  => sub { IO::Handle->new },
+    },
+    orig_fh => {
+        init_arg => undef,
+        default  => sub { select },
+    },
+    pid => {
+        init_arg => undef,
+        is       => 'rw',
+        init_arg => undef,
+    },
+};
 
 our @CARP_NOT = (__PACKAGE__);
 
-has auto => (
-    is      => 'ro',
-    default => 1,
-);
-
-has encoding => (
-    is      => 'ro',
-    default => ':utf8',
-);
-
-has pager => (
-    is      => 'ro',
-    default => \&_build_pager,
-);
-
-has fh => (
-    is      => 'rw',
-    default => sub { IO::Handle->new },
-);
-
-has pid => ( is => 'rw' );
-
-has orig_fh => (
-    is      => 'ro',
-    default => sub { select },
-);
-
 sub _build_pager {
     my $self = shift;
 
@@ -59,16 +55,23 @@ sub _build_pager {
 
 sub BUILD {
     my $self = shift;
-    $self->open if $self->auto;
+    $self->open;
+    select $self->fh if $self->auto;
 }
 
 sub open {
     my $self = shift;
-    return unless -t $self->orig_fh and !$self->fh->opened;
+
+    return $self->fh if $self->fh->opened;
+
+    if ( not -t $self->orig_fh ) {
+        $self->fh( $self->orig_fh );
+        return;
+    }
 
     my $pager = $self->pager || return;
 
-    local $ENV{LESS} = $ENV{LESS} // '-FXeR';
+    local $ENV{LESS} = $ENV{LESS} // '-FSXeR';
     local $ENV{MORE} = $ENV{MORE} // '-FXer' unless $^O eq 'MSWin32';
 
     $self->pid( CORE::open( $self->fh, '|-', $pager ) )
@@ -78,8 +81,6 @@ sub open {
       or Carp::cluck "Could not set bindmode: $!";
 
     $self->fh->autoflush(1);
-
-    select $self->fh;
 }
 
 sub close {
@@ -87,7 +88,7 @@ sub close {
     return unless $self->fh && $self->fh->opened;
 
     select $self->orig_fh;
-    $self->fh->close;
+    $self->fh->close if $self->fh ne $self->orig_fh;
 }
 
 sub DESTROY {
@@ -95,16 +96,30 @@ sub DESTROY {
     $self->close;
 }
 
+# Functions
 my $pager;
 
-sub on {
-    my $class = shift;
-    $pager //= $class->new(@_);
+sub start_pager {
+    $pager //= __PACKAGE__->new(@_);
     $pager->open;
+    select $pager->fh;
 }
 
-sub off {
-    $pager->close if $pager;
+sub stop_pager {
+    $pager // return;
+    $pager->close;
+    select( $pager->orig_fh );
+}
+
+sub page {
+    my $text  = shift;
+    my $close = not $pager;
+
+    $pager //= __PACKAGE__->new( @_, auto => 0 );
+    $pager->open;
+    my $ok = $pager->fh->printflush($text);
+    $pager->close if $close;
+    $ok;
 }
 
 1;
@@ -119,29 +134,27 @@ OptArgs2::Pager - pipe output to a system (text) pager
 
 =head1 VERSION
 
-0.0.12_2 (2022-01-27)
+2.0.0 (2022-10-05)
 
 =head1 SYNOPSIS
 
-    # If you want to test this synopsis example you will
-    # want to prevent OptArgs2::Pager setting default
-    # environment values which cause pagers to exit on short
-    # inputs
-    # $ENV{LESS} = $ENV{MORE} = '';
+    use OptArgs2::Pager 'start_pager', 'page', 'stop_pager';
 
-    use OptArgs2::Pager;
+    # One-shot output to a pager
+    page("this goes to a page with page()\n" x 50);
 
-    # Functions
-    OptArgs2::Pager->on;
-    print "This text goes to a pager\n";
+    # Or make the pager filehandle the default
+    start_pager();
+    print "This text also goes pager by default\n" x 50;
 
-    OptArgs2::Pager->off;
-    print "This text goes directly to STDOUT\n";
+    stop_pager();
+    print "This text goes straight to STDOUT\n";
 
     # Scoped
-    my $pager = OptArgs2::Pager->new;
-    print "Back to a pager\n";
-    undef $pager;
+    {
+        my $pager = OptArgs2::Pager->new;
+        print "Back to a pager by default\n" x 50;
+    }
     print "Back to STDOUT\n";
 
 =head1 DESCRIPTION
@@ -155,14 +168,23 @@ is selected again.
 
 =head1 FUNCTIONS
 
-=head2 OptArgs2::Pager->on(%ARGS)
+=head2 page($string, [%ARGS])
 
-Creates a (global singleton) pager using C<%ARGS> (passed directly to
-C<new()> below) and keeps it alive until C<off()> is called.
+An all-in-one function to start a pager (using the optional C<%ARGS>
+passed directly to C<new()> below), send it a C<$string>, and close it.
+If a pager is already running when this is called (due to a previous
+C<start_pager()>) it will reused and left open. Returns the response
+from the underlying printflush().
 
-=head2 OptArgs2::Pager->off()
+=head2 start_pager(%ARGS)
 
-Stops the global pager.
+Create a pager using C<%ARGS> (passed directly to C<new()> below) and
+makes it the default output file handle.
+
+=head2 stop_pager()
+
+Make the original file handle (usually STDOUT) the default again.
+Closes the pager input, letting it know that no more content is coming.
 
 =head1 CONSTRUCTOR
 
@@ -172,8 +194,9 @@ The C<new()> constuctor takes the following arguments.
 
 =item C<< auto => 1 >>
 
-By default the pager is opened when the object is created. Set C<auto>
-to a false value to inhibit this behaviour.
+By default the pager is selected as the default filehandle when the
+object is created. Set C<auto> to a false value to inhibit this
+behaviour.
 
 =item C<< encoding => ':utf8' >>
 
@@ -228,6 +251,13 @@ pager is already running.
 
 =back
 
+=head1 ENVIRONMENT
+
+Already mentioned above is the check for C<$PAGER> when choosing which
+pager to run. Additionally, OptArgs2 temporarily sets C<$LESS> to
+C<-FSXeR> and C<$MORE> to C<-FXer> if they are unset at the time the
+pager is opened.
+
 =head1 SEE ALSO
 
 L<IO::Pager> - does something similar by mucking directly with STDOUT
